KGenerator

Struct KGenerator 

pub struct KGenerator<'a, D: OutputSizeUser, U> { /* private fields */ }
Deterministic generator for the ephemeral scalar k as used by (EC)DSA.

Implementations

Source

impl<'a, D, U> KGenerator<'a, D, U>
where D: BlockSizeUser + Digest, U: Unsigned + Encoding,

pub fn new(x: &[u8], h: &[u8], data: &[u8], q: &'a U) -> Self

Initialize k generator.

Accepts the following parameters and inputs:

  • x: secret key
  • h: raw hash/digest of input message
  • data: additional associated data, e.g. CSRNG output used as added entropy
  • q: field modulus
pub fn fill_next_k(&mut self, k: &mut [u8])

Generate a candidate k value.

This may be called repeatedly in the event a particular k is unsuitable, e.g. the resulting r value is zero.